:mod:`euphorie.client.client`
============================

.. module:: euphorie.client.client

.. autointerface:: IClient

.. autoclass:: Client

Account support
---------------

.. autoclass:: ClientUserProvider

.. autoclass:: ClientLocalRolesProvider

Traversal logic
---------------

.. autoclass:: ClientPublishTraverser
